============
Installation
============

Using pip
=========

If you don't have ``pip`` you should probably me your life easier and get it,
the installation instructions can be found `here <https://pip.pypa.io/en/latest/installing.html>`_. Once you have it type

    $ pip install chemtools 
